const { createClient, cacheExchange, fetchExchange } = require("urql");

const GQLClient = createClient({
    url: process.env.GQL_URL,
    exchanges: [cacheExchange, fetchExchange]
});

/**
 * Generate a GQL query for a list of profiles.
 * @param {import("./proto").RawSummoner[]} profiles 
 * @returns {String}
 */
function GQLProfileQuery(profiles) {
    let counter = 0;
    return "query Profiles {" + profiles.map((profile) => {

        counter++;

        return `profile${counter - 1}: yilSummoner(summoner: {shard: ${profile.shard.toUpperCase()}, puuid: "${profile.puuid}"}) {
        name,
        tagLine,
        profileIconId,
        s3Url,
        protected
      }`;

    }) + "}";

}

module.exports = { GQLProfileQuery, GQLClient };